@@ -10,7 +10,7 @@ use parent qw(
     IO::Async::Notifier
 );
 
-our $VERSION = '3.019'; # VERSION
+our $VERSION = '3.020'; # VERSION
 
 =encoding utf8
 
@@ -174,6 +174,15 @@ async sub watch_keyspace {
     return $combined;
 }
 
+# Helper for XGROUP, recent versions of the API split that out into
+# separate two-word commands in the manual so this is here to support
+# any legacy code which calls `->xgroup`.
+sub xgroup {
+    my ($self, $cmd, @args) = @_;
+    my $method = "xgroup_" . lc($cmd);
+    return $self->$method(@args);
+}
+
 =head1 METHODS - Internal
 
 =cut
